@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,7 +34,7 @@ public:
     explicit SelectHeadersWidget(QWidget *parent = nullptr);
     ~SelectHeadersWidget();
 
-    QString headers() const;
+    Q_REQUIRED_RESULT QString headers() const;
     void setListHeaders(const QMap<QString, QString> &lst, const QStringList &selectedHeaders);
     void addNewHeader(const QString &header);
 private:
@@ -52,7 +52,7 @@ public:
     explicit SelectHeadersDialog(QWidget *parent = nullptr);
     ~SelectHeadersDialog();
 
-    QString headers() const;
+    Q_REQUIRED_RESULT QString headers() const;
     void setListHeaders(const QMap<QString, QString> &lst, const QStringList &selectedHeaders);
 
 private:
