@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -40,7 +40,7 @@ SieveEditorGraphicalModeWidget::SieveEditorGraphicalModeWidget(QWidget *parent)
     : SieveEditorGraphicalModeWidgetAbstract::SieveEditorGraphicalModeWidgetAbstract(parent)
 {
     QVBoxLayout *vlay = new QVBoxLayout(this);
-    vlay->setMargin(0);
+    vlay->setContentsMargins(0, 0, 0, 0);
 
     mSplitter = new QSplitter;
     mSplitter->setChildrenCollapsible(false);
