@@ -1,4 +1,4 @@
-/* Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -72,7 +72,7 @@ void SieveEditorAbstractWidget::slotImport()
         }
     }
     const QString filter = i18n("*.siv;;sieve files (*.siv);;all files (*)");
-    QPointer<QFileDialog> fdlg(new QFileDialog(this, i18n("Import Script Sieve"), QString(), filter));
+    QPointer<QFileDialog> fdlg(new QFileDialog(this, i18nc("@title:window", "Import Script Sieve"), QString(), filter));
     fdlg->setFileMode(QFileDialog::ExistingFile);
     if (fdlg->exec() == QDialog::Accepted) {
         const QStringList fileNames = fdlg->selectedFiles();
