@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,7 +19,6 @@
 #include "ksieveui/scriptsparsing/parsingutil.h"
 #include <kmanagesieve/sievejob.h>
 #include <QXmlStreamReader>
-#include <QDebug>
 #include <KLocalizedString>
 
 using namespace KSieveUi;
@@ -85,7 +84,7 @@ void ParseUserScriptJob::slotGetResult(KManageSieve::SieveJob *job, bool success
     if (result) {
         emitSuccess(lst);
     } else {
-        emitError(i18n("Script parsing error"));
+        emitError(i18n("Script parsing error."));
     }
 }
 
